@@ -63,12 +63,15 @@ class Canvas:
 
 
     # Draw the canvas on the screen (terminal)
-    def draw(self):
+    def draw(self, return_at_bottom: bool = True):
         for pos, char in self.changes.items():
             self.chars[pos[1]][pos[0]] = char
 
             print(cursor_move(pos) + char, end="")
 
+            if return_at_bottom:
+                print(cursor_move((0, self.size[1])))
+
         # Clear the changes list (dict)
         self.changes = {}
 
@@ -88,6 +91,31 @@ def get_escape():
     else:
         raise EngineError("No support for Windows for now :(")
 
+# Return a color escape sequence from RGB/HEX color code
+def color_escape(value, mode="rgb"):
+    assert mode in ("rgb", "hex"), f"Unknown color mode: {mode}"
+
+    esc = get_escape()
+
+    if mode == "hex":
+        value = value.strip("#")
+        colors = []
+
+        HEX_LEN = 6
+
+        for i in range(0, HEX_LEN, 2):
+            color = value[i:i+2]  # Str representing a color band in HEX
+
+            colors.append(int(color, 16))  # Convert the value to decimal
+    else:
+        assert len(value) == 3, "RGB values should contain 3 exactly bands"
+
+        colors = value
+
+    seq = f"{esc}[38;2;{';'.join(colors)}m"
+
+    return seq
+    
 # Return a cursor moving escape sequence (to be printed)
 def cursor_move(pos: Pos):
     escape = get_escape()
